pub struct ConnectionHealthCheck { /* private fields */ }Expand description
Health check for monitoring active connection count.
This check verifies that the node has at least a minimum number of active connections. Having too few connections may indicate network issues, configuration problems, or that the node is isolated from the network.
Status Determination
Healthy: Active connections >= min_connectionsDegraded: Active connections < min_connections
Example
use elara_runtime::health::{ConnectionHealthCheck, HealthCheck};
use elara_runtime::node::Node;
use std::sync::Arc;
let node = Arc::new(Node::new());
let check = ConnectionHealthCheck::new(node, 3);
let result = check.check();Implementations
Sourceimpl ConnectionHealthCheck
impl ConnectionHealthCheck
Sourcepub fn new(node: Arc<Node>, min_connections: usize) -> Self
pub fn new(node: Arc<Node>, min_connections: usize) -> Self
Creates a new ConnectionHealthCheck.
Arguments
node- Arc reference to the Node to monitormin_connections- Minimum number of active connections for healthy status
Example
use elara_runtime::health::ConnectionHealthCheck;
use elara_runtime::node::Node;
use std::sync::Arc;
let node = Arc::new(Node::new());
let check = ConnectionHealthCheck::new(node, 3);Sourcepub fn min_connections(&self) -> usize
pub fn min_connections(&self) -> usize
Returns the configured minimum connections threshold.