pub struct MemoryHealthCheck { /* private fields */ }Expand description
Health check for monitoring memory usage.
This check monitors the process memory usage and compares it against a configured maximum threshold. Excessive memory usage can lead to OOM kills, performance degradation, and system instability.
Uses the sysinfo crate to obtain real memory usage statistics.
Status Determination
Healthy: Memory usage < max_memory_mbUnhealthy: Memory usage >= max_memory_mb
Example
use elara_runtime::health::{MemoryHealthCheck, HealthCheck};
let check = MemoryHealthCheck::new(1800); // 1800 MB limit
let result = check.check();Implementations
Sourceimpl MemoryHealthCheck
impl MemoryHealthCheck