TimeDriftCheck

Struct TimeDriftCheck 

pub struct TimeDriftCheck { /* private fields */ }
Health check for monitoring time drift.

This check monitors the time drift between the local node and the network consensus time. Excessive time drift can cause synchronization issues, event ordering problems, and state divergence.

Status Determination

  • Healthy: |time_drift| < max_drift_ms
  • Degraded: |time_drift| >= max_drift_ms

Example

use elara_runtime::health::{TimeDriftCheck, HealthCheck};
use elara_runtime::node::Node;
use std::sync::Arc;

let node = Arc::new(Node::new());
let check = TimeDriftCheck::new(node, 100); // 100ms max drift
let result = check.check();

Implementations

Source

impl TimeDriftCheck

pub fn new(node: Arc<Node>, max_drift_ms: i64) -> Self

Creates a new TimeDriftCheck.

Arguments
  • node - Arc reference to the Node to monitor
  • max_drift_ms - Maximum acceptable time drift in milliseconds
Example
use elara_runtime::health::TimeDriftCheck;
use elara_runtime::node::Node;
use std::sync::Arc;

let node = Arc::new(Node::new());
let check = TimeDriftCheck::new(node, 100);
pub fn max_drift_ms(&self) -> i64

Returns the configured maximum drift threshold in milliseconds.