pub struct StateDivergenceCheck { /* private fields */ }Expand description
Health check for monitoring state convergence.
This check monitors the state reconciliation engine to ensure that state is converging properly across the network. State divergence can indicate network partitions, bugs in the reconciliation logic, or other serious issues.
Status Determination
Healthy: State is converging normallyDegraded: State convergence is slow or stalledUnhealthy: State divergence detected
Example
use elara_runtime::health::{StateDivergenceCheck, HealthCheck};
use elara_runtime::node::Node;
use std::sync::Arc;
let node = Arc::new(Node::new());
let check = StateDivergenceCheck::new(node);
let result = check.check();Implementations
Sourceimpl StateDivergenceCheck
impl StateDivergenceCheck
Sourcepub fn with_threshold(node: Arc<Node>, max_pending_events: usize) -> Self
pub fn with_threshold(node: Arc<Node>, max_pending_events: usize) -> Self
Creates a new StateDivergenceCheck with a custom threshold.
Arguments
node- Arc reference to the Node to monitormax_pending_events- Maximum pending events before degraded status
Example
use elara_runtime::health::StateDivergenceCheck;
use elara_runtime::node::Node;
use std::sync::Arc;
let node = Arc::new(Node::new());
let check = StateDivergenceCheck::with_threshold(node, 500);Sourcepub fn max_pending_events(&self) -> usize
pub fn max_pending_events(&self) -> usize
Returns the configured maximum pending events threshold.